DiscriminantSize

Enum DiscriminantSize 

pub enum DiscriminantSize {
    Size1,
    Size2,
    Size4,
}
Represents the possible sizes in bytes of the discriminant of a variant type in the component model

Variants



Size1

8-bit discriminant



Size2

16-bit discriminant



Size4

32-bit discriminant

Implementations

Source

impl DiscriminantSize

pub const fn from_count(count: usize) -> Option<Self>

Calculate the size of discriminant needed to represent a variant with the specified number of cases.

pub const fn byte_size(&self) -> u32

Returns the size, in bytes, of this discriminant